@@ -2,3 +2,5 @@ from .active_manager import ActiveManager
 from .available_manager import AvailableManager
 from .polymorphic_active_manager import PolymorphicActiveManager
 from .polymorphic_available_manager import PolymorphicAvailableManager
+from .current_site_manager import GCurrentSiteManager
+from .polymorphic_current_site_manager import GPolymorphicCurrentSiteManager
