@@ -1,17 +1,18 @@
 from setuptools import setup, find_packages
 from os import path
-from m2r import convert
-from django.conf import settings
 
 
-with open(path.join(settings.BASE_DIR, '..', 'README.md'), encoding='utf-8') as f:
-    long_description = convert(f.read())
+here = path.join(path.abspath(path.dirname(__file__)), 'garpix_utils')
+
+with open(path.join(here, 'README.md'), encoding='utf-8') as f:
+    long_description = f.read()
 
 setup(
     name='garpix_utils',
-    version='1.2.0',
+    version='1.7.0',
     description='',
     long_description=long_description,
+    long_description_content_type='text/markdown',
     url='https://github.com/garpixcms/garpix_utils',
     author='Garpix LTD',
     author_email='info@garpix.com',
